@@ -1,4 +1,4 @@
-from PasswordCardGenerator import PasswordCard
+from PasswordCardGenerator import PasswordCard, Web
 from random import choices, randint
 from os import path
 import argparse
@@ -101,9 +101,11 @@ parser = argparse.ArgumentParser(
 )
 
 # adding the arguments
+parser.add_argument("--web", action="store_true", help="Start the Web version")
 parser.add_argument(
     "keyword", nargs="+",
-    help="The keyword that is needed for the Password Card (use !GENERATE to generate a keyword). Spaces will be replaced with dots (.)"
+    help="The keyword that is needed for the Password Card (use !GENERATE to generate a keyword). Spaces will be "
+         "replaced with dots (.) "
 )
 parser.add_argument("-t", "--txt", action="store_true", help="Saves the Password Card as a text file")
 parser.add_argument("-p", "--png", action="store_true", help="Saves the Password Card as a PNG ")
@@ -113,6 +115,9 @@ parser.add_argument("--pwd", action="store_true", help="Gets the Password for [k
 # getting the args
 args = parser.parse_args()
 
+if args.web:
+    Web.main.run()
+
 # generating keyword if needed
 keyword, generated = '.'.join(args.keyword), False
 if keyword.upper() == "!GENERATE":
